@@ -21,6 +21,10 @@
 #include "tbx_timing.h"
 #endif
 
+#ifdef __MINGW32__
+#include <windows.h>
+#endif
+
 #define tbx_unlikely(x) __builtin_expect(!!(x), 0)
 
 #include "fxt.h"
@@ -178,10 +182,22 @@ fut_header (unsigned long code, ... )
 #else /* PROFILE_NEW_FORMAT */
 
 #ifndef MARCEL
+#ifdef __MINGW32__
+#ifdef __i386__
+  #define ma_cmpxchg(ptr,o,n) \
+	InterlockedCompareExchange((ptr),(n),(o))
+#elif defined (__x86_64__)
+  #define ma_cmpxchg(ptr,o,n) \
+	InterlockedCompareExchange64((ptr),(n),(o))
+#else
+#error TODO test the long size
+#endif
+#else
 /* poor man's cmpxchg,  supprimer lorsque tbx implmentera cmpxchg lui-mme */
 #define ma_cmpxchg(ptr,o,n) \
 	__sync_val_compare_and_swap((ptr), (o), (n))
 #endif
+#endif
 
 static unsigned long trash_buffer[8];
 extern int allow_fut_flush;
@@ -212,7 +228,11 @@ unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec,
 #  ifdef USE_GETTID
 		rec->tid = syscall(SYS_gettid);
 #  else
+#ifdef __MINGW32__
+		rec->tid = GetCurrentThread();
+#else
 		rec->tid = pthread_self();
+#endif
 #  endif
 	} else {
 		rec->tid = 0;
