@@ -1,5 +1,5 @@
 /*
-*  Copyright (C) 2004, 2011 Samuel Thibault <samuel.thibault@ens-lyon.org>
+*  Copyright (C) 2004, 2011-2012 Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -355,4 +355,8 @@ enum {
 	FXT_BLOCK_TRACES_USER_RAW64,
 };
 
+unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec, unsigned long code);
+int fut_flush( char* filename, void* next_slot, int record_flush_events );
+void __fut_reset_pointers();
+
 #endif /* __FXT_INTERNAL_H */
